==> vee_2.4-5.tar.gz: vee-2.4/src/child/__BASIC__.py <==
# -*- coding: utf-8 -*-
#    Copyright (C) 2005 Spike^ekipS <spikeekips@gmail.com>
#
#    http://vee.kldp.net
#
#       This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import gtk
import GConf, Conf, i18n

_ = i18n.gettext()

class egg :

	CHILD_TYPE = None
	WIDGET = None

	EMULATION = "xterm"
	ARGUMENT = str()
	DIRECTORY = str()
	FORK_COMMAND = str()
	UNIT_FONT_DELM = 1000
	RANGE_FONT_SIZE = (10000, 30000)

	GCONF_CLIENT = None

	IS_REMOVED = False

	SETTING = dict()

	def __init__ (self, **kwargs) :
		"""
		* Must be implemented
		"""

		self.GCONF_CLIENT = GConf.Client()
		self.GCONF_CLIENT.add_dir(Conf.LOCAL_ROOT)

		if kwargs.has_key("setting") and type(kwargs["setting"]) is dict :
			self.SETTING = kwargs["setting"]

	def __del__ (self) :
		del(self.WIDGET)

	def exit (self) :
		"""
		Safely child widget be exited.

		return : None
		"""
		self.WIDGET.destroy()

	def make (self) :
		"""
		* Must be implemented

		Make child widget

		return : None
		"""

		pass

	def reset (self) :
		"""
		Clear up the disty spot in the child widget, this was used
		mainly in VTE widget

		return : None
		"""
		pass

	def set_notify (self) :
		pass

	def get_title (self) :
		"""
		Get the window title

		return : str
		"""

		return self.WIDGET.get_window_title()

	def increase_font (self, size=int()) :
		"""
		Increase child widget font.
		"""

		pass

	def decrease_font (self, size=int()) :
		"""
		Decrease child widget font.
		"""

		pass

	def set_font (self, fontDescription) :
		"""
		Set the font of child widget

		arg : pango.FontDescription
		return : None
		"""

		pass

	def set_font_from_string (self, fontname) :
		"""
		Set the font of child widget

		arg : string fontname
		return : None
		"""

		pass

	def activate_dnd (self) :
		self.WIDGET.connect("drag_data_received", self.on_drag_received)

		self.WIDGET.drag_dest_set(gtk.DEST_DEFAULT_MOTION |
			gtk.DEST_DEFAULT_HIGHLIGHT |
			gtk.DEST_DEFAULT_DROP,
			Conf.DND_TARGET_TABLE, gtk.gdk.ACTION_COPY)

	def on_drag_received \
			(self, widget, context, x, y, selection, targetType, time) :
		return

import State

class tab :

	STATE = None
	SETTING = dict()
	NOTEBOOK = None
	LIST_TAB = list()

	WIDGET = None

	EGG = None
	KWARGS = dict()

	def __init__ (self, state, **kwargs) :

		if not isinstance(state, State.State) :
			raise ValueError, _("state must be included.")
		else :
			self.STATE = state
			if not self.STATE.DATA.has_key("notebook") :
				raise ValueError, _("notebook was not instantiated.")
			else :
				self.NOTEBOOK = self.STATE.DATA["notebook"]

			if not self.STATE.DATA.has_key("tab-list") :
				raise ValueError, _("tab-list does not exist.")
			else :
				self.LIST_TAB = self.STATE.DATA["tab-list"]

		if kwargs.has_key("setting") and type(kwargs["setting"]) is dict :
			self.SETTING = kwargs["setting"]

		self.GCONF_CLIENT = GConf.Client()
		self.GCONF_CLIENT.add_dir(Conf.LOCAL_ROOT)

		self.KWARGS = kwargs

	def __del__ (self) :
		del(self.KWARGS)
		del(self.EGG)
		del(self.WIDGET)

	def getEgg (self) :
		"""
		create the instance of Egg as member property, self.EGG.

		return None
		"""

		self.EGG = egg()
		self.EGG.make()

	def make (self) :
		self.EGG = self.getEgg()

		self.WIDGET = TAB.One(state=self.STATE)
		self.WIDGET.addChild(self.EGG)

		self.append_tab()
		self.connect()

	def append_tab (self) :
		self.LIST_TAB.add(self.WIDGET)

	def connect (self) :
		# set window title
		self.EGG.WIDGET.connect("window-title-changed", self.on_change_title)

	def on_change_title (self, widget) :
		__title = self.WIDGET.Child.get_title()

		self.set_title(__title)
		self.WIDGET.INSTANCE_LABEL.set_label(__title)

	def set_title (self, strings) :
		self.STATE.DATA["root-widget"].set_title(_("%s : VEE") % strings)

"""
Description
-----------


ChangeLog
---------


Usage
-----

"""

__author__ =  "Spike^ekipS <spikeekips@gmail.com>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "__BASIC__.py"

==> vee_2.4-6.tar.gz: vee-2.4/src/child/__BASIC__.py <==
# -*- coding: utf-8 -*-
#    Copyright (C) 2005 Spike^ekipS <spikeekips@gmail.com>
#
#    http://vee.kldp.net
#
#       This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import gtk
import GConf, Conf, i18n, Setting

_ = i18n.gettext()

class egg :

	CHILD_TYPE = None
	WIDGET = None

	EMULATION = "xterm"
	ARGUMENT = str()
	DIRECTORY = str()
	FORK_COMMAND = str()
	UNIT_FONT_DELM = 1000
	RANGE_FONT_SIZE = (10000, 30000)

	GCONF_CLIENT = None

	IS_REMOVED = False

	SETTING = None

	def __init__ (self, **kwargs) :
		"""
		* Must be implemented
		"""

		self.GCONF_CLIENT = GConf.Client()
		self.GCONF_CLIENT.add_dir(Conf.LOCAL_ROOT)

		if kwargs.has_key("setting") and type(kwargs["setting"]) is dict :
			self.SETTING = Setting.DATA(kwargs["setting"])
		else :
			self.SETTING = Setting.DATA()

	def __del__ (self) :
		del(self.WIDGET)

	def exit (self) :
		"""
		Safely child widget be exited.

		return : None
		"""
		self.WIDGET.destroy()

	def make (self) :
		"""
		* Must be implemented

		Make child widget

		return : None
		"""

		pass

	def reset (self) :
		"""
		Clear up the disty spot in the child widget, this was used
		mainly in VTE widget

		return : None
		"""
		pass

	def set_notify (self) :
		pass

	def get_title (self) :
		"""
		Get the window title

		return : str
		"""

		return self.WIDGET.get_window_title()

	def increase_font (self, size=int()) :
		"""
		Increase child widget font.
		"""

		pass

	def decrease_font (self, size=int()) :
		"""
		Decrease child widget font.
		"""

		pass

	def set_font (self, fontDescription) :
		"""
		Set the font of child widget

		arg : pango.FontDescription
		return : None
		"""

		pass

	def set_font_from_string (self, fontname) :
		"""
		Set the font of child widget

		arg : string fontname
		return : None
		"""

		pass

	def activate_dnd (self) :
		self.WIDGET.connect("drag_data_received", self.on_drag_received)

		self.WIDGET.drag_dest_set(gtk.DEST_DEFAULT_MOTION |
			gtk.DEST_DEFAULT_HIGHLIGHT |
			gtk.DEST_DEFAULT_DROP,
			Conf.DND_TARGET_TABLE, gtk.gdk.ACTION_COPY)

	def on_drag_received \
			(self, widget, context, x, y, selection, targetType, time) :
		return

import State

class tab :

	STATE = None
	SETTING = dict()
	NOTEBOOK = None
	LIST_TAB = list()

	WIDGET = None

	EGG = None
	KWARGS = dict()

	def __init__ (self, state, **kwargs) :

		if not isinstance(state, State.State) :
			raise ValueError, _("state must be included.")
		else :
			self.STATE = state
			if not self.STATE.DATA.has_key("notebook") :
				raise ValueError, _("notebook was not instantiated.")
			else :
				self.NOTEBOOK = self.STATE.DATA["notebook"]

			if not self.STATE.DATA.has_key("tab-list") :
				raise ValueError, _("tab-list does not exist.")
			else :
				self.LIST_TAB = self.STATE.DATA["tab-list"]

		if kwargs.has_key("setting") and type(kwargs["setting"]) is dict :
			self.SETTING = kwargs["setting"]

		self.GCONF_CLIENT = GConf.Client()
		self.GCONF_CLIENT.add_dir(Conf.LOCAL_ROOT)

		self.KWARGS = kwargs

	def __del__ (self) :
		del(self.KWARGS)
		del(self.EGG)
		del(self.WIDGET)

	def getEgg (self) :
		"""
		create the instance of Egg as member property, self.EGG.

		return None
		"""

		self.EGG = egg()
		self.EGG.make()

	def make (self) :
		self.EGG = self.getEgg()

		self.WIDGET = TAB.One(state=self.STATE)
		self.WIDGET.addChild(self.EGG)

		self.append_tab()
		self.connect()

	def append_tab (self) :
		self.LIST_TAB.add(self.WIDGET)

	def connect (self) :
		# set window title
		self.EGG.WIDGET.connect("window-title-changed", self.on_change_title)

	def on_change_title (self, widget) :
		__title = self.WIDGET.Child.get_title()

		self.set_title(__title)
		self.WIDGET.INSTANCE_LABEL.set_label(__title)

	def set_title (self, strings) :
		self.STATE.DATA["root-widget"].set_title(_("%s : VEE") % strings)

"""
Description
-----------


ChangeLog
---------


Usage
-----

"""

__author__ =  "Spike^ekipS <spikeekips@gmail.com>"
__version__=  "0.1"
__nonsense__ = ""

__file__ = "__BASIC__.py"
